import 'package:flutter/material.dart';

class ErrorBox extends StatelessWidget {
  const ErrorBox(
    this._onTap, {
    double? width,
    double? height,
    String? message,
    Color? boxColor,
    Color? fontColor,
    Color? borderColor,
    Key? key,
  })  : _width = width,
        _height = height,
        _message = message,
        _boxColor = boxColor,
        _fontColor = fontColor,
        _borderColor = borderColor,
        super(key: key);

  final double? _width;
  final double? _height;
  final void Function() _onTap;
  final String? _message;
  final Color? _boxColor;
  final Color? _fontColor;
  final Color? _borderColor;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
          color: _boxColor ?? const Color(0xffF8D7D9),
          borderRadius: const BorderRadius.all(Radius.circular(5)),
          border: Border.all(color: _borderColor ?? const Color(0xffF5C6Cb))),
      height: _height ?? 80,
      width: _width ?? 250,
      child: Flex(
        direction: Axis.horizontal,
        children: [
          Expanded(
              flex: 10,
              child: Container(
                margin: const EdgeInsets.only(left: 10),
                alignment: Alignment.centerLeft,
                child: Text(
                  _message ?? "Username or password incorrect. Kindly recheck & try again.",
                  style: TextStyle(color: _fontColor ?? const Color(0xff721D24)),
                ),
              )),
          Expanded(
            child: GestureDetector(
              onTap: _onTap,
              child: Container(
                alignment: Alignment.topRight,
                child: const CloseButton(),
              ),
            ),
          )
        ],
      ),
    );
  }
}

class CloseButton extends StatelessWidget {
  const CloseButton(
      {double? width, double? height, double? iconSize, Color? color, Color? iconColor, Key? key})
      : _width = width,
        _height = height,
        _iconSize = iconSize,
        _color = color,
        _iconColor = iconColor,
        super(key: key);

  final double? _width;
  final double? _height;
  final double? _iconSize;
  final Color? _color;
  final Color? _iconColor;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(top: 5, right: 5),
      width: _width ?? 18,
      height: _height ?? 18,
      decoration: BoxDecoration(
          color: _color ?? const Color(0xffDC3545),
          borderRadius: const BorderRadius.all(Radius.circular(360))),
      child: Center(
        child: Icon(
          Icons.close,
          size: _iconSize ?? 18,
          color: _iconColor ?? Colors.white,
        ),
      ),
    );
  }
}
